@@ -344,12 +344,6 @@
 #define __NV_ENABLE_MSI EnableMSI
 #define NV_REG_ENABLE_MSI NV_REG_STRING(__NV_ENABLE_MSI)
 
-#if defined(NVCPU_ARM) || defined(NV_VMWARE)
-#define __NV_ENABLE_MSI_DEFAULT 1
-#else
-#define __NV_ENABLE_MSI_DEFAULT 0
-#endif
-
 /*
  * Option: MapRegistersEarly
  *
@@ -464,7 +458,7 @@ NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
 NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, 1);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, __NV_ENABLE_MSI_DEFAULT);
+NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
 
 #if defined(NV_LINUX) || defined(NV_VMWARE)
