@@ -13,7 +13,6 @@
 #include "nv.h"
 #include "nv-freebsd.h"
 
-
 void* os_pci_init_handle(
     NvU32 domain,
     NvU8  bus,
@@ -43,64 +42,83 @@ void* os_pci_init_handle(
     return (void *) dev;
 }
 
-NvU8 os_pci_read_byte(
+RM_STATUS os_pci_read_byte(
     void *handle,
-    NvU8 offset
+    NvU32 offset,
+    NvU8 *value
 )
 {
-    return pci_read_config((device_t) handle, offset, 1);
+    if (offset >= 0x100) {
+        *value = 0xff;
+        return RM_ERR_NOT_SUPPORTED;
+    }
+    *value = pci_read_config((device_t) handle, offset, 1);
+    return RM_OK;
 }
 
-NvU16 os_pci_read_word(
+RM_STATUS os_pci_read_word(
     void *handle,
-    NvU8 offset
+    NvU32 offset,
+    NvU16 *value
 )
 {
-    return pci_read_config((device_t) handle, offset, 2);
+    if (offset >= 0x100) {
+        *value = 0xffff;
+        return RM_ERR_NOT_SUPPORTED;
+    }
+    *value = pci_read_config((device_t) handle, offset, 2);
+    return RM_OK;
 }
 
-NvU32 os_pci_read_dword(
+RM_STATUS os_pci_read_dword(
     void *handle,
-    NvU8 offset
+    NvU32 offset,
+    NvU32 *value
 )
 {
-    return pci_read_config((device_t) handle, offset, 4);
+    if (offset >= 0x100) {
+        *value = 0xffffffff;
+        return RM_ERR_NOT_SUPPORTED;
+    }
+    *value = pci_read_config((device_t) handle, offset, 4);
+    return RM_OK;
 }
 
-void os_pci_write_byte(
+RM_STATUS os_pci_write_byte(
     void *handle,
-    NvU8 offset,
-    NvU8 value
+    NvU32 offset,
+    NvU8  value
 )
 {
+    if (offset >= 0x100)
+        return RM_ERR_NOT_SUPPORTED;
+
     pci_write_config((device_t) handle, offset, value, 1);
+    return RM_OK;
 }
 
-void os_pci_write_word(
+RM_STATUS os_pci_write_word(
     void *handle,
-    NvU8  offset,
+    NvU32 offset,
     NvU16 value
 )
 {
+    if (offset >= 0x100)
+        return RM_ERR_NOT_SUPPORTED;
+
     pci_write_config((device_t) handle, offset, value, 2);
+    return RM_OK;
 }
 
-void os_pci_write_dword(
+RM_STATUS os_pci_write_dword(
     void *handle,
-    NvU8  offset,
+    NvU32 offset,
     NvU32 value
 )
 {
+    if (offset >= 0x100)
+        return RM_ERR_NOT_SUPPORTED;
+
     pci_write_config((device_t) handle, offset, value, 4);
+    return RM_OK;
 }
-
-BOOL os_pci_device_present(
-    NvU16 vendor,
-    NvU16 device
-)
-{
-    if (pci_find_device(vendor, device))
-        return TRUE;
-    return FALSE;
-}
-
